@@ -13,6 +13,6 @@ def render_template(path, context):
     path = os.path.join(os.path.dirname(dploi_fabric.__file__), path)
     if not isinstance(context, Context):
         context = Context(context)
-    template_file = open(path)
-    template = Template(template_file.read())
-    return template.render(context)
\ No newline at end of file
+    with open(path) as template_file:
+        template = Template(template_file.read())
+    return template.render(context)
